import argparse
import asyncio
from twscrape import API, gather
from twscrape.logger import set_log_level

def parse_args():
    parser = argparse.ArgumentParser(description="Twitter Scraper")
    parser.add_argument("--accounts", nargs='+', required=True, help="List of account credentials in the format 'username:password:email:mail_password'")
    parser.add_argument("--search_query", required=True, help="Search query")
    return parser.parse_args()

async def main():
    args = parse_args()

    api = API()  # or API("path-to.db") - default is `accounts.db`

    for account in args.accounts:
        username, password, email, mail_password = account.split(':')
        await api.pool.add_account(username, password, email, mail_password)

    await api.pool.login_all()

    # search
    async for tweet in api.search(args.search_query, limit=10):
        print(tweet.json())

if __name__ == "__main__":
    asyncio.run(main())
