
import { type Logger } from 'winston';
import { ConnectionOptions, type Job } from 'bullmq';
import path from 'node:path';
import fs from 'node:fs';
import { IVod } from "./vods.js";

export interface ITaskOptions {
    env: NodeJS.ProcessEnv;
    logger: Logger;
    job: Job;
    connection: ConnectionOptions;
}


export interface ITask {
    name: string;
    runTask: IRunTaskFunction;
}

export interface IRunTaskFunction {
    (options: ITaskOptions): Promise<any>;
}


export default class Task {
    private logger: Logger; // Assuming you have a Logger type

    constructor(opts: { logger: Logger }) {
        this.logger = opts.logger;
    }
}


export interface IIssueDefinition {
    name: string;
    check: ((env: NodeJS.ProcessEnv, logger: Logger, vod: IVod) => Promise<boolean>);
    solution: string;
}


export async function loadTaskDefinitions(logger: Logger, tasksDirectory: string, taskList: string[]): Promise<ITask[]> {
    const activeTasks = await Promise.all(
        taskList.map(async (taskName) => {
            const taskModulePath = path.join(tasksDirectory, `${taskName}.ts`); // Assuming your task files have .js extension
            logger.log({ level: 'info', message: `📁 ${taskModulePath}` });
            if (fs.existsSync(taskModulePath)) {
                const taskModule = await import(taskModulePath);
                if (taskModule.runTask) {
                    return taskModule;
                }
            }
            return null;
        })
    );
    return activeTasks.filter((task) => !!task)
}