import { PutObjectCommand, S3Client } from '@aws-sdk/client-s3';
import { createId } from '@paralleldrive/cuid2';
import path from 'node:path';
import fs from 'node:fs';
import { B2_ENDPOINT, B2_REGION, B2_KEY, B2_SECRET } from './env.ts';

const urlPrefix = 'https://f000.backblazeb2.com/b2api/v1/b2_download_file_by_id?fileId='

export async function uploadToB2 (env: NodeJS.ProcessEnv, filePath: string) {
  const keyName = `${createId()}-${path.basename(filePath)}`
  const bucketName = env.B2_BUCKET
  console.log(`uploadToB2 begin. bucketName:${bucketName}`)
  const s3 = new S3Client({
    endpoint: B2_ENDPOINT,
    region: B2_REGION,
    credentials: {
      accessKeyId: B2_KEY,
      secretAccessKey: B2_SECRET,
    }
  });
  var params = {Bucket: bucketName, Key: keyName, Body: fs.createReadStream(filePath)};
  const res = await s3.send(new PutObjectCommand(params));
  if (!res.VersionId) {
    const msg = 'res was missing VersionId'
    throw new Error(msg)
  }
  return {
    uploadId: res.VersionId,
    key: keyName,
    url: `${urlPrefix}${res.VersionId}`
  }
}
