import { format, formatInTimeZone, utcToZonedTime, toDate, zonedTimeToUtc } from 'date-fns-tz';
import { parse } from 'date-fns';

const safeDateFormatString: string = "yyyyMMdd'T'HHmmss'Z'"
const localTimeZone = Intl.DateTimeFormat().resolvedOptions().timeZone;

export function getSafeDate (text: string): string {
  const date = utcToZonedTime(text, 'UTC');
  return format(date, safeDateFormatString, { timeZone: 'UTC' });
}


export function getDateFromSafeDate(safeDate: string): Date {
  const date = parse(safeDate, safeDateFormatString, new Date())
  const utcDate = zonedTimeToUtc(date, 'UTC')
  return utcDate;
}


export function getMonthsBetweenDates(startDate: Date, endDate: Date): [Date, Date][] {
  const months: [Date, Date][] = [];

  while (startDate <= endDate) {
    const year = startDate.getUTCFullYear();
    const month = startDate.getUTCMonth();
    const firstDayOfMonth = new Date(Date.UTC(year, month, 1));
    const lastDayOfMonth = new Date(Date.UTC(year, month + 1, 0));

    months.push([firstDayOfMonth, lastDayOfMonth]);

    // Move to the next month
    startDate.setUTCMonth(startDate.getUTCMonth() + 1);
  }

  return months;
}