import express, { Request, Response, NextFunction } from "express";
import methodOverride from "method-override";
import { RegisterRoutes } from "../dist/futureporn-qa/routes/routes.js";
import { ValidateError } from "tsoa";
import { HttpStatusCode } from "./http-status-code.js";


interface IError {
  status?: number;
  fields?: string[];
  message?: string;
  name?: string;
}



export const registerRoutes = (app: express.Express) => {
    app
      .use(express.urlencoded({ extended: true }))
      .use(express.json())
      .use(methodOverride())
      .use((_req: Request, res: Response, next: NextFunction) => {
        res.header("Access-Control-Allow-Origin", "*");
        res.header(
          "Access-Control-Allow-Headers",
          `Origin, X-Requested-With, Content-Type, Accept, Authorization`
        );
        next();
      });
  
    RegisterRoutes(app);
  
    const getErrorBody = (err: unknown) => {
      if (err instanceof ValidateError) {
        return {
          message: err.message,
          status: HttpStatusCode.BAD_REQUEST,
          fields: err.fields,
          name: err.name,
        };
      } else {
        return {
          message: "UNKNOWN_ERROR",
          status: HttpStatusCode.INTERNAL_SERVER_ERROR,
        };
      }
    };
  
    app.use(
      (
        err: IError,
        _req: express.Request,
        res: express.Response,
        next: express.NextFunction
      ) => {
        console.error(err);
        
  
        const body = getErrorBody(err);
        res.status(body.status).json(body);
        next();
      }
    );
  };