import { ICrawl } from '../models/crawl.js';
import { Queue } from 'bullmq';
import { REDIS_HOST, REDIS_PORT } from '../env.js';
import { default as Redis } from 'ioredis'

/**
 * @example {
 *   "username": "projektmelody",
 *   "vtuberId": 1
 * }
 */
export type ICreateCrawlRequest = {
    username: string;
    vtuberId: number;
}

/**
 * @example {
 *   "username": "projektmelody",
 *   "since": "2023-10-02T00:00:00.000Z",
 *   "until": "2023-10-31T00:00:00.000Z",
 *   "vtuberId": 1
 * }
 */
export type ICreateCrawlMonthRequest = {
    username: string;
    since: Date;
    until: Date;
    vtuberId: number;
}


export async function queueCrawl(req: ICreateCrawlRequest): Promise<ICrawl> {

    const connection = new Redis.default({
        port: parseInt(REDIS_PORT),
        host: REDIS_HOST,
        maxRetriesPerRequest: null,
    });

    const { username, vtuberId } = req;

    // add crawl job to queue
    const queue: Queue = new Queue('crawlTwitter', {
        connection
    });
    
    const job = await queue.add(
        'crawlTwitter',
        {
            username: username,
            vtuberId: vtuberId,
        }
    )

    return {
        username: username,
        jobId: job?.id || '',
        vtuberId: vtuberId,
    }
}

export async function queueCrawlMonth(req: ICreateCrawlMonthRequest): Promise<any> {

    const connection = new Redis.default({
        port: parseInt(REDIS_PORT),
        host: REDIS_HOST,
        maxRetriesPerRequest: null,
    });

    const { username, since, until, vtuberId } = req;

    // add crawl job to queue
    const queue: Queue = new Queue('crawlTwitterMonth', {
        connection
    });
    
    const job = await queue.add(
        'crawlTwitterMonth',
        {
            username: username,
            since: since,
            until: until,
            vtuberId: vtuberId,
        }
    )

    return {
        username: username,
        since: since,
        until: until,
        vtuberId: vtuberId,
    }
}