import { IVtuber } from "./vtubers.ts";
import { Logger } from "winston";
import { IStrapiTweet } from "./tweets.ts";
import qs from 'qs';
import { STRAPI_API_KEY, STRAPI_URL } from "./env.ts";


export interface IStream {
    id: number;
    attributes: {
        date: string;
        vtuber: IVtuber;
    }
}

export interface IStreamResponse {
    data: IStream[];
    meta: {
        pagination: {
            total: number;
        }
    }
}

export async function createStream (logger: Logger, tweet: IStrapiTweet, vtuberId: number): Promise<IStream> {
    logger.log({ level: 'debug', message: `Searching for stream with related tweet id_str=${tweet.attributes.id_str}` });
    const existingStreamQuery = qs.stringify({
        populate: {
            tweet: {
                fields: ['id_str'],
            },
        },
        filters: {
            tweet: {
                id_str: {
                    $eq: tweet.attributes.id_str
                }
            }
        }
    })
    const existingStreamRes = await fetch(`${STRAPI_URL}/api/streams?${existingStreamQuery}`, {
        method: 'GET',
        headers: {
            'authorization': `Bearer ${STRAPI_API_KEY}`,
            'content-type': 'application/json'
        },
    });
    const existingStreamJson = await existingStreamRes.json() as IStreamResponse;
    logger.log({ level: 'debug', message: `Here is the existingStreamJson=${JSON.stringify(existingStreamJson)}` });
    if (!!existingStreamJson?.data && !!existingStreamJson?.data[0]) return existingStreamJson.data[0];

    logger.log({ level: 'debug', message: `There is not an existing stream in Strapi with tweet matching id_str=${tweet.attributes.id_str} so we create it.` });
    const streamRes = await fetch(`${STRAPI_URL}/api/streams`, {
        method: 'POST',
        headers: {
            'authorization': `Bearer ${STRAPI_API_KEY}`,
            'content-type': 'application/json'
        },
        body: JSON.stringify({
            data: {
                date: new Date(tweet.attributes.date).toISOString(),
                date_str: tweet.attributes.date,
                tweet: tweet.id,
                vtuber: vtuberId
            }
        })
    })
    const bod = await streamRes.json();
    if (!streamRes.ok) {
        throw new Error(`failed to create stream entry in Strapi. status=${streamRes.status}, statusText=${streamRes.statusText} body=${bod}`);
    }

    logger.log({ level: 'info', message: `created stream in Strapi. bod=${JSON.stringify(bod)}` });
    return bod.data

}