import qs from 'qs';
import { strapiUrl } from './constants.js'
import { unmarshallTag, ITag, IToyTag } from './tags.js';
import { IVod } from './vods.js';

export interface ITagVodRelation {
    id: number;
    tag: ITag | IToyTag;
    vod: IVod;
}


export interface ITagVodRelations {
    data: ITagVodRelation[];
    pagination: {
        page: number;
        pageSize: number;
        pageCount: number;
        total: number;
    }
}

export function unmarshallTagVodRelation(d: any): ITagVodRelation {
    return {
        id: d.id,
        tag: unmarshallTag(d.attributes.tag.data),
        vod: d.attributes.vod
    }
}

export async function getTagVodRelationsForVtuber(vtuberId: number, page: number = 1, pageSize: number = 25): Promise<ITagVodRelations> {
    // get the tag-vod-relations where the vtuber is the vtuber we are interested in.
    const query = qs.stringify(
        {
            populate: {
                tag: {
                    fields: ['id', 'name'],
                    populate: {
                        toy: {
                            fields: ['linkTag', 'make', 'model', 'image2'],
                            populate: {
                                linkTag: {
                                    fields: ['name']
                                }
                            }
                        }
                    }
                },
                vod: {
                    populate: {
                        vtuber: {
                            fields: ['slug']
                        }
                    }
                }
            },
            filters: {
                vod: {
                    vtuber: {
                        id: {
                            $eq: vtuberId
                        }
                    }
                },
                tag: {
                    toy: {
                        linkTag: {
                            name: {
                                $notNull: true
                            }
                        }
                    }
                }
            },
            pagination: {
                page: page,
                pageSize: pageSize
            },
            sort: {
                id: 'desc'
            }
        }
    )
    // we need to return an IToys object
    // to get an IToys object, we have to get a list of toys from tvrs.


    return fetch(`${strapiUrl}/api/tag-vod-relations?${query}`)
        .then((res) => res.json())
        .then((j) => {
            const tvrs = {
                data: j.data.map(unmarshallTagVodRelation),
                pagination: j.meta.pagination
            }
            return tvrs
        })
}

