import { IRunTaskFunction, ITaskOptions } from "../Task.js";
import { projektMelodyEpoch } from "../constants.js";
import { getMonthsBetweenDates } from "../dates.js";
import { Queue } from "bullmq";

export const name = 'crawlTwitter';
export const runTask: IRunTaskFunction = async ({ logger, env, job, connection }: ITaskOptions) => {
    // @todo this is the initial crawl function
    //       this function does not do any searching.
    //       instead, this function queues many twitter searches ("crawlTwitterMonth" task)
    //       one search per month since projektmelody epoch until present date.
    const { username, vtuberId } = job.data;
    if (!vtuberId) throw new Error('vtuberId was not present in job data');
    if (!username) throw new Error('username was not present in job data');


    const queue: Queue = new Queue('crawlTwitterMonth', {
        connection
    });



    const months = getMonthsBetweenDates(projektMelodyEpoch, new Date());


    // for each month, queue a search
    for (const month of months) {
        await queue.add(
            'crawlTwitterMonth',
            {
                since: month[0],
                until: month[1],
                username: username,
                vtuberId: vtuberId
            }
        )
    }


    return months

}