

import { strapiUrl } from "../constants.js";
import fetch from 'node-fetch';
import { getVod } from '../vods.js';
import { ITaskOptions, IRunTaskFunction } from "../Task.js";
import { IJobData } from "../types.js";



export const name = 'deleteThumbnail';

export const runTask: IRunTaskFunction = async ({ logger, env, job }: ITaskOptions) => {
    const jobData = job.data as IJobData;
    const vod = await getVod(jobData.id, env);

    if (!vod?.attributes?.thumbnail?.data?.id) throw new Error('vod.thumbnail was missing');
    const res = await fetch(`${strapiUrl}/api/b2-files/${vod?.attributes?.thumbnail?.data?.id}`, {
        method: 'DELETE',
        headers: {
            'Authorization': `Bearer ${env.STRAPI_API_KEY}`
        }
    });
    if (!res.ok) {
        logger.log({ level: 'info', message: `Response code: ${res.status} (ok:${res.ok})` })
        const msg = `Could not delete thumbnail due to fetch response error ${res.status} ${res.body}`
        logger.log({ level: 'error', message: msg });
        throw new Error(msg);
    } else {
        logger.log({ level: 'info', message: `  thumbnail ${vod.attributes.thumbnail.data.id} deleted.` })
        return
    }
}

