import fetch, { AbortError } from 'node-fetch';
import { ITaskOptions, IRunTaskFunction,　IIssueDefinition } from "../Task.js";
import { multiaddrToUri } from '@multiformats/multiaddr-to-uri';
import { IPFS_CLUSTER_HTTP_API_MULTIADDR } from '../env.js';

// /api/v0/pin/add

// https://docs.ipfs.tech/reference/kubo/rpc/#api-v0-pin-add

// processOrder.ts
// import { Boss, Job } from 'pg-boss';

// export class ProcessOrderTask {
//     private boss: Boss;

//     constructor(boss: Boss) {
//         this.boss = boss;
//     }

//     async executeJob(job: Job<any>) {
//         // Your task logic here
//         const data = job.data;
//         // Perform the actual work here
//         // ...
//         job.done(); // Mark the job as completed
//     }
// }


/**
 * identifyVideoSrcHashIssues
 * 
 * This does an in-depth check of the CID
 * 
 * Takes about 3 minutes to determine if a CID is reachable or not
 * 
 */

export const name = 'identifyVideoSrcHashIssues';

// const issueDefinitions: IIssueDefinition[] = [
//     {
//         name: 'videoSrcHashUnreachable',
//         check: async (vod, env) => {
//             // if (!vod?.thumbnail?.data?.attributes?.cdnUrl) return true;
//             // else return false;

//         },
//         solution: 'pinVideoSrcHash'
//     },
// ];

export const runTask: IRunTaskFunction = async ({ logger, env, job, connection }: ITaskOptions) => {
    logger.log({ level: 'info', message: `🐓 identifyVideoSrcHashIssues runTask begin. 🌱` });

    // for (const iDef of issueDefinitions) {
    //     const isProblem = await iDef.check(vod, env);
    //     const status = isProblem ? '🔴 FAIL' : '🟢 PASS';
    //     logger.log({ level: 'info', message: `${status} ${iDef.name} ${isProblem ? `(queueing ${iDef.solution} to solve.)` : ''}` });
    //     if (isProblem) {
    //         logger.log({ level: 'info', message: `🚩 VOD Problem detected. Adding ${iDef.solution} task to the queue.` })
    //         const queue = new Queue(iDef.solution, {
    //             connection
    //         })
    //         queue.add(iDef.solution, { id: vod.id });
    //     }
    // }



    const uri = multiaddrToUri(IPFS_CLUSTER_HTTP_API_MULTIADDR);
    const controller = new AbortController();
    const signal = controller.signal;

    const timeout = setTimeout(() => {
        controller.abort();
    }, 60*3000);

    try {
        logger.log({ level: 'info', message: `>> IDK IDK uri=${uri}` })
        const res = await fetch(`${uri}/api/v0/pins/${job.data.CID}`, { signal });
        if (res.ok) {
            clearTimeout(timeout); // Cancel the timeout
            logger.log({ level: 'info', message: `🌚 identifyVideoSrcHashIssues runTask end. 🌊` });
            return false; 
        } else {
            logger.log({ level: 'warn', message: `>> fetch failed !! res.status=${res.status} controller.signal=${controller.signal}` })
            return true; 
        }
    } catch (error) {
        logger.log({ level: 'error', message: `>> fetch failed due to error ${JSON.stringify(error)}` })
        return true; 
    }




}